@@ -15,12 +15,13 @@
 from __future__ import print_function
 
 import logging
-from six.moves.urllib.parse import urlparse
 import subprocess
 import time
 
 from keystoneclient.openstack.common.apiclient import exceptions
 import keystoneclient.v2_0.client as ksclient
+from six.moves.urllib.parse import urlparse
+
 from os_cloud_config.utils import clients
 
 LOG = logging.getLogger(__name__)
@@ -82,6 +83,8 @@ SERVICES = {
     'swift': {
         'description': 'Swift Object Storage Service',
         'type': 'object-store',
+        'path': '/v1/AUTH_%(tenant_id)s',
+        'admin_path': '/v1',
         'port': 8080,
         'ssl_port': 13080,
     },
